@@ -1,11 +1,13 @@
+# -*- coding: utf-8 -*-
+
 from flask import make_response, jsonify
 
 
 class ErrorResponse(object):
-
     _INTERNAL_ERROR = {'errorMessage': 'Internal error'}
     _NOT_FOUND_BIND_FUNC = {'errorMessage': 'Not found the function bind to the route'}
-    _INVALID_RESPONSE_FORMAT = {'errno': 403, 'error': 'Invalid scf response format. please check your scf response format.'}
+    _INVALID_RESPONSE_FORMAT = {'errno': 403,
+                                'error': 'Invalid scf response format. please check your scf response format.'}
 
     _STATUS_CODE_403 = 403
     _STATUS_CODE_502 = 502
@@ -35,4 +37,4 @@ class ErrorResponse(object):
         if msg and isinstance(msg, str):
             err_msg = {'errorMessage': msg}
 
-        return make_response(jsonify(err_msg), ErrorResponse._STATUS_CODE_403)
\ No newline at end of file
+        return make_response(jsonify(err_msg), ErrorResponse._STATUS_CODE_403)
