@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 from tcfcli.common.tcsam.tcsam_macro import TcSamMacro as tsmacro
 from tcfcli.common.user_exceptions import InvalidTemplateException
 from tcfcli.common.macro import MacroRuntime
@@ -6,6 +8,7 @@ class Runtime(object):
     RUNTIME = {
         MacroRuntime.node610: MacroRuntime.cmd_node610,
         MacroRuntime.node89: MacroRuntime.cmd_node89,
+        MacroRuntime.node89_s: MacroRuntime.cmd_node89_s,
         MacroRuntime.python36: MacroRuntime.cmd_python36,
         MacroRuntime.python27: MacroRuntime.cmd_python27,
     }
