@@ -1,5 +1,6 @@
-import click
-import json
+# -*- coding: utf-8 -*-
+
+import traceback
 from tcfcli.cmds.cli import __version__
 from tencentcloud.common import credential
 from tencentcloud.common.profile.client_profile import ClientProfile
@@ -8,11 +9,12 @@ from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentClo
 from tencentcloud.scf.v20180416 import scf_client, models
 from tcfcli.common.user_config import UserConfig
 from tcfcli.common.user_exceptions import LogsException
+from tcfcli.common.operation_msg import Operation
 
 
 class ScfBaseClient(object):
-
     CLOUD_API_REQ_TIMEOUT = 5
+
     def __init__(self, region=None):
         uc = UserConfig()
         self._cred = credential.Credential(secretId=uc.secret_id, secretKey=uc.secret_key)
@@ -30,8 +32,9 @@ class ScfBaseClient(object):
         try:
             return apifunc(req)
         except TencentCloudSDKException as err:
-            requestId =  err.get_request_id()
+            Operation(err, err_msg=traceback.format_exc(), level="ERROR").no_output()
+            requestId = err.get_request_id()
             errmsg = err.get_message()
             if requestId:
-                errmsg = errmsg + "\nRequestId:{}".format(requestId)
+                errmsg = errmsg + " RequestId:{}".format(requestId)
             raise LogsException(errmsg)
