@@ -19,9 +19,7 @@ class TcSamMacro(object):
     LocalZipFile = "LocalZipFile"
     CosBucketName = "CosBucketName"
     CosObjectName = "CosObjectName"
-
-
-
+    Role = "Role"
 
     TrApiGw = "APIGW"
     TrCMQ = "CMQ"
@@ -46,3 +44,5 @@ class TriggerMacro(object):
     Topic = "Topic"
     MaxMsgNum = "MaxMsgNum"
     Offset = "Offset"
+    ServiceId = "ServiceId"
+    Message = "Message"
