@@ -1,6 +1,10 @@
+# -*- coding: utf-8 -*-
+
 import os
 import io
 import yaml
+import traceback
+from tcfcli.common.operation_msg import Operation
 from tcfcli.common.user_exceptions import ContextException
 from tcfcli.libs.utils.yaml_parser import yaml_parse
 
@@ -16,4 +20,5 @@ class Template(object):
             try:
                 return yaml_parse(f.read())
             except (ValueError, yaml.YAMLError) as ex:
-                raise ContextException("Parse template failed: {}".format(str(ex)))
\ No newline at end of file
+                Operation(ex, err_msg=traceback.format_exc(), level="ERROR").no_output()
+                raise ContextException("Parse template failed: {}".format(str(ex)))
