@@ -1,7 +1,8 @@
+# -*- coding: utf-8 -*-
+
 import yaml
 import json
 
-
 def yaml_dump(dict_to_dump, file_path):
     with open(file_path, "w") as f:
         yaml.safe_dump(dict_to_dump, f, default_flow_style=False)
@@ -10,5 +11,5 @@ def yaml_dump(dict_to_dump, file_path):
 def yaml_parse(yaml_file):
     try:
         return json.loads(yaml_file)
-    except ValueError:
+    except ValueError as e:
         return yaml.safe_load(yaml_file)
